#
# spec file for package ghc-http-client-restricted
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name http-client-restricted
%global pkgver %{pkg_name}-%{version}
Name:           ghc-%{pkg_name}
Version:        0.1.0
Release:        1.26
Summary:        Restricting the servers that http-client will use
License:        MIT
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-base-devel
BuildRequires:  ghc-base-prof
BuildRequires:  ghc-crypton-connection-devel
BuildRequires:  ghc-crypton-connection-prof
BuildRequires:  ghc-data-default-devel
BuildRequires:  ghc-data-default-prof
BuildRequires:  ghc-http-client-devel
BuildRequires:  ghc-http-client-prof
BuildRequires:  ghc-http-client-tls-devel
BuildRequires:  ghc-http-client-tls-prof
BuildRequires:  ghc-network-bsd-devel
BuildRequires:  ghc-network-bsd-prof
BuildRequires:  ghc-network-devel
BuildRequires:  ghc-network-prof
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-utf8-string-devel
BuildRequires:  ghc-utf8-string-prof
ExcludeArch:    %{ix86}

%description
Addition to the http-client and http-client-tls libraries, that restricts the
HTTP servers that can be used.

This is useful when a security policy needs to eg, prevent connections to HTTP
servers on localhost or a local network, or only allow connections to a
specific HTTP server.

It handles restricting redirects as well as the initial HTTP connection, and it
also guards against DNS poisoning attacks.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library
development files.

%package -n ghc-%{pkg_name}-doc
Summary:        Haskell %{pkg_name} library documentation
Requires:       ghc-filesystem
BuildArch:      noarch

%description -n ghc-%{pkg_name}-doc
This package provides the Haskell %{pkg_name} library documentation.

%package -n ghc-%{pkg_name}-prof
Summary:        Haskell %{pkg_name} profiling library
Requires:       ghc-%{pkg_name}-devel = %{version}-%{release}
Supplements:    (ghc-%{pkg_name}-devel and ghc-prof)

%description -n ghc-%{pkg_name}-prof
This package provides the Haskell %{pkg_name} profiling library.

%prep
%autosetup -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc CHANGELOG

%files -n ghc-%{pkg_name}-doc -f ghc-%{pkg_name}-doc.files
%license LICENSE

%files -n ghc-%{pkg_name}-prof -f ghc-%{pkg_name}-prof.files

%changelog
* Tue Aug  1 2023 Peter Simons <psimons@suse.com>
- Update http-client-restricted to version 0.1.0.
  http-client-restricted (0.1.0) unstable; urgency=medium
  * Switch from connection to crypton-connection in order to support
    being used with tls-1.7, which use crypton rather than cryptonite.
  - - Joey Hess <id@joeyh.name>  Tue, 01 Aug 2023 18:45:47 -0400
* Thu Mar 30 2023 Peter Simons <psimons@suse.com>
- Updated spec file to conform with ghc-rpm-macros-2.5.2.
* Wed Feb  9 2022 Peter Simons <psimons@suse.com>
- Update http-client-restricted to version 0.0.5.
  http-client-restricted (0.0.5) unstable; urgency=medium
  * Deal with raw IPv6 addresses correctly, stripping square
    brackets before passing on to name resolution.
    (The same fix was made in http-client 0.7.11, which this depends on.)
    Thanks, Robert Vollmert.
  - - Joey Hess <id@joeyh.name>  Wed, 09 Feb 2022 11:24:29 -0400
* Wed Jan 13 2021 psimons@suse.com
- Update http-client-restricted to version 0.0.4.
  http-client-restricted (0.0.4) unstable; urgency=medium
  * Update to http-client 0.7.
  - - Joey Hess <id@joeyh.name>  Tue, 12 Jan 2021 13:37:00 -0400
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Tue Aug 18 2020 Peter Simons <psimons@suse.com>
- Replace %%setup -q with the more modern %%autosetup macro.
* Tue Jul 21 2020 psimons@suse.com
- Add http-client-restricted at version 0.0.3.
